cluster.assign.torus returns clustering assignment for data
given icp.torus objects, which can be constructed with
icp.torus.
plot.clus.torus plots clustering results, which is given by cluster.obj object, with some options.
cluster.assign.torus(icp.object, data = NULL, level = NULL)# S3 method for cluster.obj
plot(
x,
assignment = c("outlier", "log.density", "posterior", "mahalanobis"),
overlay = FALSE,
out = FALSE,
...
)
an object must be an icp.torus object, which contains
all values to compute the conformity score constructed with icp.torus,
or a hyperparam.torus object which is generated by hyperparam.torus.
n x d matrix of toroidal data on \([0, 2\pi)^d\)
or \([-\pi, \pi)^d\).
If data = NULL, then data within the icp.object is used.
a scalar in \([0,1]\). If argument icp.object is an icp.torus object,
the default value for level is 0.1. If argument icp.object is
a hyperparam.torus object and level = NULL, then level
is set as the optimal level hyperparam.torus$alphahat.
cluster.obj object
A string. One of "outlier", "log.density", "posterior", "mahalanobis". Default is "outlier".
A boolean index which determines whether plotting ellipse-intersections on clustering plots.
Default is FALSE.
An option for returning the ggplot object. Default is FALSE.
additional parameter for ggplot2::ggplot()
clustering assignment for data, given icp.torus objects
cluster.id.by.log.densitycluster assignment result based on approximate log-density.
cluster.id.by.posteriorcluster assignment result based on the posterior probability.
cluster.id.outliercluster assignment result which regards data not included in conformal prediction set as outliers.
cluster.id.by.Mah.distcluster assignment result based on Mahalanobis distance.
levelused level which determines the size of clusters(conformal prediction set).
datainput data which are assigned to each cluster.
icp.torusicp.torus object which is used for cluster assignment.
Jung, S., Park, K., & Kim, B. (2021). Clustering on the torus by conformal prediction. The Annals of Applied Statistics, 15(4), 1583-1603.
Gilitschenski, I., & Hanebeck, U. D. (2012, July). A robust computational test for overlap of two arbitrary-dimensional ellipsoids in fault-detection of kalman filters. In 2012 15th International Conference on Information Fusion (pp. 396-401). IEEE.
# NOT RUN {
data <- toydata1[, 1:2]
icp.torus <- icp.torus(data, model = "kmeans",
kmeansfitmethod = "general",
J = 4, concentration = 25)
level <- 0.1
cluster.assign.torus(icp.torus, level = level)
# }
Run the code above in your browser using DataLab